textcat_profile_db(x, id, ...)as.character.x.textcat_options for the
(current) default options. The names of the arguments are partially
matched atextcnt in package
n, split and useBytes
corresponding to the respective arguments, and option reduce
setting argument marker as needed. N-grams listed in option
ignore are removed, and only the most frequent remaining ones
retained, with the maximal number given by option size. The
options employed for building the db are stored in the db. There is a c method for combining profile dbs provided
that these have identical options.
Unless the profile db uses bytes rather than characters (i.e., option
bytes is TRUE), the text documents in x should be
encoded in UTF-8.